# Advent of Code Utility Classes

A bunch of utility classes for Advent of Code problems. As I have worked on Advent of Code problems a number of utility classes have been created that help solve problems.

- Point2D - 2D point
- Point3D - 3D point
- Stack - Simple implementation of a Stack (LIFO)
